# tanjun.commands

Standard implementations of Tanjun's command objects.

::: tanjun.commands.menu
    options:
        show_root_heading: true

::: tanjun.commands.message
    options:
        show_root_heading: true

::: tanjun.commands.slash
    options:
        show_root_heading: true
